from django import urls
from django.conf import settings

try:
    from importlib.metadata import version

    __version__ = version('django-absoluteuri')
except ImportError:
    import pkg_resources

    __version__ = pkg_resources.get_distribution('django-absoluteuri').version


def build_absolute_uri(path):
    """Turn a relative URL into an absolute URL."""
    from django.contrib.sites.models import Site
    site = Site.objects.get_current()
    return '{protocol}://{domain}{path}'.format(
        protocol=getattr(settings, 'ABSOLUTEURI_PROTOCOL', 'http'),
        domain=site.domain,
        path=path
    )


def reverse(*args, **kwargs):
    """Reverse a URL and make it absolute."""
    path = urls.reverse(*args, **kwargs)
    return build_absolute_uri(path)



import warnings

from django.test import TestCase
from django.template import Template, Context
from django.urls import re_path

import absoluteuri


def view(request, *args, **kwargs):
    pass


urlpatterns = [
    re_path(r'^foo/$', view, name='view'),
    re_path(r'^foo/(?P<foo>\w+)/$', view, name='view'),
    re_path(r'^foo/(\d+)/$', view, name='view'),
]


class AbsoluteURITestCase(TestCase):
    def render_template(self, template, is_secure=False, **context_data):
        context = Context(context_data)
        return Template(template).render(context)

    def test_absoluteuri_tag(self):
        template = "{% load absoluteuri %}{% absoluteuri 'view' %}"
        rendered = self.render_template(template)
        self.assertEqual(rendered, 'http://example.com/foo/')

        kwarg_tmpl = "{% load absoluteuri %}{% absoluteuri 'view' foo='bar' %}"
        rendered2 = self.render_template(kwarg_tmpl)
        self.assertEqual(rendered2, 'http://example.com/foo/bar/')

        arg_tmpl = "{% load absoluteuri %}{% absoluteuri 'view' 12 %}"
        rendered3 = self.render_template(arg_tmpl)
        self.assertEqual(rendered3, 'http://example.com/foo/12/')

    def test_absolutize_tag(self):
        with warnings.catch_warnings(record=True) as w:
            warnings.simplefilter("always")

            template = "{% load absoluteuri %}{% absolutize path %}"
            rendered = self.render_template(template, path='/url/path/')

        self.assertEqual(rendered, 'http://example.com/url/path/')
        self.assertTrue(issubclass(w[-1].category, DeprecationWarning))

    def test_protocol_with_setting_not_set(self):
        uri = absoluteuri.build_absolute_uri('/url/path/')
        self.assertEqual(uri, 'http://example.com/url/path/')

    def test_protocol_with_setting_not_set_as_http(self):
        with self.settings(ABSOLUTEURI_PROTOCOL='http'):
            uri = absoluteuri.build_absolute_uri('/url/path/')
            self.assertEqual(uri, 'http://example.com/url/path/')

    def test_protocol_with_setting_not_set_as_https(self):
        with self.settings(ABSOLUTEURI_PROTOCOL='https'):
            uri = absoluteuri.build_absolute_uri('/url/path/')
            self.assertEqual(uri, 'https://example.com/url/path/')

    def test_absolutize_filter(self):
        template = "{% load absoluteuri %}" + \
                   "{% with url='/foo/' %}{{ url|absolutize }}{% endwith %}"
        rendered = self.render_template(template)
        self.assertEqual(rendered, "http://example.com/foo/")



from __future__ import absolute_import
import warnings

from django import template

import absoluteuri

register = template.Library()


@register.simple_tag(name='absoluteuri')
def do_absoluteuri(view_name, *args, **kwargs):
    """Reverse a URL and make it absolute."""
    return absoluteuri.reverse(view_name, args=args, kwargs=kwargs)


register.filter(name='absolutize')(absoluteuri.build_absolute_uri)


@register.simple_tag(name='absolutize')
def absolutize_deprecated_tag(*args, **kwargs):
    warnings.warn(
        "{% absolutize %} tag is deprecated. Use {{ |absolutize }} filter",
        DeprecationWarning,
    )
    return absoluteuri.build_absolute_uri(*args, **kwargs)



#!/usr/bin/env python
import os
from setuptools import setup, find_packages

__doc__ = "Absolute URI functions and template tags for Django"


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

readme = read('README.rst')
changelog = read('CHANGELOG.rst')

setup(
    name='django-absoluteuri',
    version='2.0.0',
    description=__doc__,
    long_description=readme + '\n\n' + changelog,
    author='Fusionbox, Inc.',
    author_email='programmers@fusionbox.com',
    url='https://github.com/fusionbox/django-absoluteuri',
    packages=[package for package in find_packages() if package.startswith('absoluteuri')],
    install_requires=[
        'Django>=4.2',
    ],
    license="Apache 2.0",
    zip_safe=True,
    keywords='django-absoluteuri',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'Programming Language :: Python :: 3.13',
        'Programming Language :: Python :: 3.14',
    ],
)
